@@ -7,5 +7,8 @@ fn main() {
     assert!(HISTORY.insert(2));
     assert!(HISTORY.insert(3));
     assert!(!HISTORY.insert(2));
-    // panic: assert!(!HISTORY.insert(4));
+    assert!(HISTORY.contains(&1));
+    assert!(HISTORY.insert(4));
+    assert!(!HISTORY.contains(&1));
+    assert!(HISTORY.insert(5));
 }
