@@ -53,7 +53,7 @@ impl<T, const N: usize> Vec<T, N> {
         }
     }
     pub fn push(&mut self, value: T) {
-        if self.len == Self::CAPACITY {
+        if self.len == self.capacity() {
             panic!("full.");
         }
         unsafe {
@@ -75,6 +75,17 @@ impl<T, const N: usize> Vec<T, N> {
         }
     }
 }
+impl<T: Clone, const N: usize> Vec<T, N> {
+    pub fn extend_from_slice(&mut self, other: &[T]) {
+        assert!(self.len + other.len() <= self.capacity());
+
+        let buf = unsafe { slice::from_raw_parts_mut(self.as_mut_ptr(), self.len + other.len()) };
+        for item in other {
+            buf[self.len] = item.clone();
+            self.len += 1;
+        }
+    }
+}
 impl<T, const N: usize> ops::Deref for Vec<T, N> {
     type Target = [T];
 
